@@ -3,7 +3,7 @@
  */
 
 /* 
- * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kitenet.net)
+ * Copyright (c) 1995-1999 Joey Hess (pdmenu@joeyh.name)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
@@ -23,6 +23,3 @@
 
 /* Edit this file to change the default colors pdmenu will use. */
 #include "colors.h"
-
-/* Edit this file to change the strings that are built into pdmenu. */
-#include "strings.h"
