@@ -3,7 +3,7 @@
  */
 
 /* 
- * Copyright (c) 1997 by Joey Hess (joey@kitenet.net) and William Thompson 
+ * Copyright (c) 1997-1999 by Joey Hess (pdmenu@joeyh.name) and William Thompson
  * (wakko@kitenet.net)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
@@ -12,8 +12,11 @@
 #include "mouse.h"
 #include "error.h"
 #include "screen.h"
+#include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
+#include <libintl.h>
+#define _(String) gettext (String)
 
 /* Display an error. The parameters work like printf() */
 void Error(const char *fmt, ...) {
@@ -25,7 +28,7 @@ void Error(const char *fmt, ...) {
   Screen_Reset();
 
   va_start(arglist, fmt);
-  fprintf(stderr, ERROR_HEADER);
+  fprintf(stderr, _("pdmenu error: "));
   vfprintf(stderr, fmt, arglist);
   fprintf(stderr, "\n");
   va_end(arglist);
