@@ -3,7 +3,7 @@
  */
 
 /* 
- * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kitenet.net)
+ * Copyright (c) 1995-1999 Joey Hess (pdmenu@joeyh.name)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
@@ -14,25 +14,29 @@
 /* Global variables */
 
 /* Pointer to linked list of all windows on the screen */
-Window_List_Type *CurrentWindow;
+extern Window_List_Type *CurrentWindow;
 /* Pointer to linked list of all available menus. */
-Menu_Type *menus;
+extern Menu_Type *menus;
 /* Pointer to the menu that will be modified by new rc commands. */
-Menu_Type *current_rc_menu;
+extern Menu_Type *current_rc_menu;
 
 /* Boolean variables, 0=no, 1=yes */
-int Use_Color;
-int Q_Exits;
-int Unpark_Cursor;
+extern int Use_Color;
+extern int Q_Exits;
+extern int Unpark_Cursor;
 #ifdef GPM_SUPPORT
 /* Was the mouse detected? */
-int gpm_ok;
+extern int gpm_ok;
 #endif
 /* Set when the screen has resized */
-int Want_Screen_Resize;
+extern int Want_Screen_Resize;
 /* Use old-style look if set. */
-int Retro;
+extern int Retro;
 /* Don't use high bit line drawing chars. */
-int Lowbit;
+extern int Lowbit;
+/* Draw borders with spaces. */
+extern int Borderspace;
 /* Don't use 2 or 8 for up and down if set */
-int Numeric;
+extern int Numeric;
+/* Use superhot hot keys */
+extern int Superhot;
