@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kitenet.net)
+ * Copyright (c) 1995-1999 Joey Hess (pdmenu@joeyh.name)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
@@ -11,10 +11,12 @@
 #include "keyboard.h"
 #include "pdmenu.h"
 #include "inputbox.h"
+#include "pdstring.h"
 #include <string.h>
-#include <strings.h>
 #include <stdlib.h>
 #include "slang.h"
+#include <libintl.h>
+#define _(String) gettext (String)
 
 /* 
  * Draw the input box on screen.
@@ -48,7 +50,7 @@ Conditional_String *DoInputBox (char *title, char *contents) {
 
   curspos=strlen(ret->value);
 
-  DrawBase(INPUTHELP);
+  DrawBase(_("Press Enter when done, or Esc to cancel"));
   DrawInputBox(title);
 	
   while (1) {
@@ -72,7 +74,7 @@ Conditional_String *DoInputBox (char *title, char *contents) {
 				
 	/* This isn't done too well -- there's some flicker. */
 	Force_Redraw();
-	DrawBase(INPUTHELP);
+	DrawBase(_("Press Enter when done, or Esc to cancel"));
 	DrawInputBox(title);
       }
       break;
@@ -137,6 +139,7 @@ Conditional_String *EditTags(char *s) {
 	  tagtitle=malloc(i - tagtitlestart + 1);
 	  strncpy(tagtitle,(char *) s + tagtitlestart,i - tagtitlestart);
 	  tagtitle[i - tagtitlestart] ='\0';
+	  tagtitle = unescape(tagtitle, ':');
 	  tagvaluestart=i+1;
 	  for (i++;i<strlen(s);i++) {
 	    if ((s[i]=='~') && (s[i-1]!='\\')) { /* End of tag */
