@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kitenet.net)
+ * Copyright (c) 1995, 1996, 1997 Joey Hess (pdmenu@joeyh.name)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
@@ -11,11 +11,23 @@
 #include "window.h"
 #include <math.h>
 #include <string.h>
-#include <strings.h>
 #include <ctype.h>
 #include "slang.h"
 #include <stdlib.h>
 #include "error.h"
+#include <libintl.h>
+#define _(String) gettext (String)
+
+char ScreenObjNames[NUMSCREENPARTS+1][LONGEST_OBJ_NAME+1]; 
+int DESKTOP;
+int TITLE;
+int BASE;
+int MENU;
+int SELBAR;
+int SHADOW;
+int MENU_HI;
+int SELBAR_HI;
+int UNSEL_MENU;
 
 /* Highlight the hotkey of a given menu item, if there is a hotkey. */
 void HighlightHotkey (Menu_Type *m,int item,int highlight_color) {
@@ -81,7 +93,7 @@ void CalcMenu (Menu_Type *m) {
   char *s;
 
   /*
-   * NOTE: if we are in B&W mode (SLtt_Use_Ansi_Colors==0), then we don't
+   * If we are in B&W mode (SLtt_Use_Ansi_Colors==0), then we don't
    * need to allocate space for shadows. 
    */
 	
@@ -310,6 +322,23 @@ int SelHotKey(Menu_Type *m, int key) {
   return 0;
 }
 
+int HotKeyMatches(Menu_Type *m, int key, int i) {
+  return m->items[i]->hotkey != -1 &&
+	    ( (key==m->items[i]->text[m->items[i]->hotkey]) || toupper(key)==m->items[i]->text[m->items[i]->hotkey] );
+}
+
+int UniqHotKeyMatches(Menu_Type *m, int key) {
+   int i = 0;
+   int n = m->num;
+   int c = 0;
+
+   if ( HotKeyMatches(m,key,m->selected) )
+      for (i=0; i<n; i+=1)
+	if ( HotKeyMatches(m,key,i) )
+	  c += 1;
+   return c == 1;
+}
+
 /* 
  * Handle input in a menu.
  * Pass it the menu to handle, and a pointer to the function to be called 
@@ -371,13 +400,19 @@ int DoMenu (Menu_Type *m,int (*MenuAction)(), void (*Ctrl_C_Action)()) {
     case '-':
     case '8':
     case SL_KEY_UP:
-      DoMenu_Up(m);
-      break;
+			if (key != '8' || ! Numeric)
+	      DoMenu_Up(m);
+			else
+				SelHotKey(m,key);
+			break;
     case '+':
     case '=': /* no need to shift for + */
     case '2':
     case SL_KEY_DOWN:
-      DoMenu_Down(m);
+			if (key != '2' || ! Numeric)
+	      DoMenu_Down(m);
+			else
+				SelHotKey(m,key);
       break;
     case ' ':
     case 22: /* ctrl-v */
@@ -403,20 +438,24 @@ int DoMenu (Menu_Type *m,int (*MenuAction)(), void (*Ctrl_C_Action)()) {
       break;
     case '\n':
     case '\r':
+    case SL_KEY_RIGHT:
       c=MenuAction(m);
       if (c!=0)
 	return c;
+      break;
     case 65535:
       break;
     default:
       c=SelHotKey(m,key);
+      if ( Superhot && UniqHotKeyMatches(m,key) )
+	return MenuAction(m);
       if (c!=0)
 	break;
       /* No hotkeys match, so use q or ESC to close the menu. */
-      if ((key=='q') || (key=='Q') || (key==27))
+      if ((key=='q') || (key=='Q') || (key==27) || (key ==SL_KEY_LEFT))
 	return Q_KEY_EXIT;
       /* They hit a bad key. Display help. */
-      DrawBase(HELPBASE);
+      DrawBase(_("Arrow keys move, Esc exits current menu, Enter runs program"));
       SLsmg_refresh();
     }
   }
@@ -447,7 +486,7 @@ void RemoveMenu(Menu_Type *m) {
 
   /* Check to see if this menu is currently visible onscreen */
   if (IsVisible(m))
-    Error(REMOVE_ONSCREEN_MENU,m->name);
+    Error(_("Attempt to remove menu \"%s\" failed: menu is on screen."),m->name);
 
   /* Check to see if this is the menu new rc lines add to. */
   /*  if (current_rc_menu == m)
@@ -476,7 +515,7 @@ void RemoveMenu(Menu_Type *m) {
   /* Remove the menu from the linked list. */
   if (m->last)
     m->last->next=m->next;
-  if (m->next)
+ if (m->next)
     m->next->last=m->last;
   else {
     /* 
