@@ -1,19 +1,19 @@
 /* 
- * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kitenet.net)
+ * Copyright (c) 1995, 1996, 1997 Joey Hess (pdmenu@joeyh.name)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
 /* This must be long enough for "selbarhi". */
-char ScreenObjNames[NUMSCREENPARTS+1][LONGEST_OBJ_NAME]; 
-int DESKTOP;
-int TITLE;
-int BASE;
-int MENU;
-int SELBAR;
-int SHADOW;
-int MENU_HI;
-int SELBAR_HI;
-int UNSEL_MENU;
+extern char ScreenObjNames[NUMSCREENPARTS+1][LONGEST_OBJ_NAME+1]; 
+extern int DESKTOP;
+extern int TITLE;
+extern int BASE;
+extern int MENU;
+extern int SELBAR;
+extern int SHADOW;
+extern int MENU_HI;
+extern int SELBAR_HI;
+extern int UNSEL_MENU;
 
 void DrawMenu(Menu_Type *,int);
 void SelMenuItem(Menu_Type *,int,int);
