@@ -5,7 +5,7 @@
 
 /* 
  * Copyright (c) 1996, 1997 by Randolph Chung <rc42@cornell.edu> and 
- * Joey Hess (joey@kitenet.net)
+ * Joey Hess (pdmenu@joeyh.name)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
@@ -44,17 +44,29 @@ int CheckMouse() {
 
     retval = select(gpm_fd+1, &rfds, NULL, NULL, &tv);
 
-    if (retval) { /* data available */
-      if ((FD_ISSET(gpm_fd, &rfds)) &&  /* data is for mice */
-	  (Gpm_GetEvent(&event))) { /* can read something */
-	if ((event.type & GPM_DOWN) && (event.buttons & GPM_B_LEFT)) 
-	  return(MOUSE_BUTTON_LEFT);
-	if ((event.type & GPM_DOWN) && (event.buttons & GPM_B_RIGHT))
-	  return(MOUSE_BUTTON_RIGHT);
-	if (event.dy > 0)
-	  return(MOUSE_DOWN);
-	if (event.dy < 0)
-	  return(MOUSE_UP);
+    if (retval > 0) { /* data available */
+      if (FD_ISSET(gpm_fd, &rfds)) {
+	  /* data is for mice */
+	switch (Gpm_GetEvent(&event)) {
+	case 1:
+	  /* can read something */
+	  if ((event.type & GPM_DOWN) && (event.buttons & GPM_B_LEFT)) 
+	    return(MOUSE_BUTTON_LEFT);
+	  if ((event.type & GPM_DOWN) && (event.buttons & GPM_B_RIGHT))
+	    return(MOUSE_BUTTON_RIGHT);
+	  if (event.dy > 0)
+	    return(MOUSE_DOWN);
+	  if (event.dy < 0)
+	    return(MOUSE_UP);
+	  break;
+	case -1:
+	  /* can read nothing */
+	  break;
+	case 0:
+	  /* disconnected */
+	  gpm_ok = 0;
+	  return(MOUSE_NOTHING);
+	} /* switch */
       } else { /* data is for keyboard */
 	return(MOUSE_NOTHING);
       } /* else */
@@ -62,7 +74,7 @@ int CheckMouse() {
   }
 }
 
-#ifdef 0
+#if 0
 void ClearMouse(void) {
   fd_set rfds;
   struct timeval tv;
@@ -97,9 +109,11 @@ int InitMouse() {
   gpm_fd=Gpm_Open(&conn, 0);
   if (gpm_fd < 0) {
     Gpm_Close();
+    gpm_active=0;
     return 0;
   }
   else {
+    gpm_active=1;
     return 1;
   }
 }
