@@ -1,7 +1,7 @@
 /* Rc file and data structure handling */
 
 /*
- * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kitenet.net)
+ * Copyright (c) 1995-2001 Joey Hess (pdmenu@joeyh.name)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
@@ -14,9 +14,14 @@
 #include <stdio.h>
 #include "pdgetline.h"
 #include <string.h>
-#include <strings.h>
 #include <ctype.h>
 #include <stdlib.h>
+#include <libintl.h>
+#include <unistd.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#define _(String) gettext (String)
 
 /*
  * Passed a menu item and a character, set the flag on the menu item that
@@ -39,6 +44,8 @@ int SetFlags(Menu_Item_Type *i,char c) {
     return i->truncate_flag=1;
   case MAKEMENU_FLAG:
     return i->makemenu_flag=1;
+  case COMMAND_FLAG:
+    return i->command_flag=1;
   }
   return 0;
 }
@@ -55,7 +62,7 @@ int SetFlags(Menu_Item_Type *i,char c) {
  */
 char ReadRc (char *fname,int type) {
   char *str, *str_p, *tmp;
-  int escaped,i,line,newflag;
+  int i,j,line,newflag;
   Menu_Item_Type *ingroup=NULL; /* points to last item we added to group */
   Menu_Item_Type *currentitem=NULL; /* the item we are adding to the menus */
   FILE *fp=NULL;
@@ -154,21 +161,29 @@ char ReadRc (char *fname,int type) {
       }
       current_rc_menu->recalc=1;
     }
+    else if (strcasecmp(tmp,TITLE_KEYWORD)==0) { /* set title */
+      free(ScreenTitle);
+      ScreenTitle=strdup(pdstrtok(NULL,FIELD_DELIM));
+    }
     else if (strcasecmp(tmp,COLOR_KEYWORD)==0) { /* color def */
       if ((tmp=unescape(pdstrtok(NULL,FIELD_DELIM),FIELD_DELIM)) == NULL ) {
 	free(str);
 	continue;
       }
-      for (i=0;i<NUMSCREENPARTS;i++)
-	if (strcasecmp(tmp,ScreenObjNames[i+1])==0) { /* match */
+      for (i=0;i<NUMSCREENPARTS;i++) {
+	if (strcasecmp(tmp,ScreenObjNames[i+1]) == 0) { /* match */
 	  if ((tmp=unescape(pdstrtok(NULL,FIELD_DELIM),FIELD_DELIM)) != NULL) {
 	    strncpy(FG[i],tmp,COLORLEN);
 	    if ((tmp=pdstrtok(NULL,FIELD_DELIM)) != NULL) {
 	      strncpy(BG[i],tmp,COLORLEN);
+	      break;
 	    }
 	  }
 	  i=NUMSCREENPARTS;
 	}
+      }
+      if (i == NUMSCREENPARTS)
+      	Error(_("%s:%i Invalid screen part name, \"%s\"."),fname,line,tmp);
     }
     else if (strcasecmp(tmp,READ_KEYWORD)==0) { /* read in another file */
       ReadRc(pdstrtok(NULL,FIELD_DELIM),RC_FILE);
@@ -179,13 +194,14 @@ char ReadRc (char *fname,int type) {
 	current_rc_menu->num++;
       }
       else
-	Error(ENDGROUP_WITHOUT_GROUP,fname,line);
+	Error(_("%s:%i \"endgroup\" found outside of group block."),fname,line);
     }
     /* Everything from here on out requires a menu be set up first. */
     else if (!menus || current_rc_menu == NULL)
-      Error(INVALID_KEYWORD,fname,line,tmp);
+      Error(_("%s:%i Invalid or misplaced keyword, \"%s\"."),fname,line,tmp);
     else if ((strcasecmp(tmp,EXEC_KEYWORD)==0) ||
 	     (strcasecmp(tmp,SHOW_MENU_KEYWORD)==0) ||
+	     (strcasecmp(tmp,HELP_TEXT_KEYWORD)==0) ||
 	     (strcasecmp(tmp,EXIT_KEYWORD)==0) ||
 	     (strcasecmp(tmp,NOP_KEYWORD)==0) ||
 	     (strcasecmp(tmp,GROUP_KEYWORD)==0) ||
@@ -214,13 +230,15 @@ char ReadRc (char *fname,int type) {
 	currentitem->type=MENU_SHOW;
       else if (strcasecmp(tmp,NOP_KEYWORD)==0)
 	currentitem->type=MENU_NOP;
+      else if (strcasecmp(tmp,HELP_TEXT_KEYWORD)==0)
+	currentitem->type=MENU_HELP_TEXT;
       else if (strcasecmp(tmp,GROUP_KEYWORD)==0) {
 	if (ingroup == NULL) {
 	  ingroup=currentitem;
 	  currentitem->type=MENU_GROUP;
 	}
 	else
-	  Error(NESTED_GROUP,fname,line);
+	  Error(_("%s:%i Nested \"group\" commands."),fname,line);
       }
       else if (strcasecmp(tmp,REMOVE_KEYWORD)==0)
 	currentitem->type=MENU_REMOVE;
@@ -229,17 +247,19 @@ char ReadRc (char *fname,int type) {
 
       currentitem->hotkey=-1; 
       if ((tmp=unescape(pdstrtok(NULL,FIELD_DELIM),FIELD_DELIM)) != NULL) {
-	escaped=0;
 	for (i=0;i<strlen(tmp)-1;i++) { /* set hotkey */
-	  if (tmp[i]==HOTKEY_SEL_CHAR && !escaped) {
+          if(tmp[i] == '\\') {
+	    for (j=i; j<strlen(tmp);j++) {
+	      tmp[j]=tmp[j+1];
+	    }
+	    i++;    /* skip past the escaped character */
+	    continue;
+	  }
+	  if (tmp[i]==HOTKEY_SEL_CHAR) {
 	    currentitem->hotkey=i;
 	    for (;i<strlen(tmp);i++) {
 	      tmp[i]=tmp[i+1];
 	    }
-	    break;
-	  }
-	  else {
-	    escaped = ((tmp[i] == '\\') && !escaped);
 	  }
 	}
 	tmp=unescape(tmp,HOTKEY_SEL_CHAR);
@@ -288,18 +308,29 @@ char ReadRc (char *fname,int type) {
 	current_rc_menu->num++;
     }
     else
-      Error(INVALID_KEYWORD,fname,line,tmp);
+      Error("%s:%i Invalid or misplaced keyword, \"%s\".",fname,line,tmp);
 
     free(str);
   }
 
-  if (type == RC_FILE)
+  if (fp == stdin) {
+    /*
+     * Make sure that we have the real tty open as stdin.
+     * You see, if a rc file is passed to pdmenu on stdin, then
+     * after the rc file is read, there is no longer stdin available
+     * for programs pdmenu launches to use.
+     */
+    int fd = open("/dev/tty", O_RDWR);
+    dup2(fd, 0);
+    close(fd);
+  }
+  else if (type == RC_FILE)
     fclose(fp);
   else if (type == RC_PREPROC)
     pclose(fp);
 
   if (ingroup != NULL)
-    Error(GROUP_WITHOUT_ENDGROUP,fname);
+    Error(_("%s: \"group\" command used without \"endgroup\"."),fname);
 
   return 1;
 }
