@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kitenet.net)
+ * Copyright (c) 1995-2003 Joey Hess (pdmenu@joeyh.name)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
@@ -15,7 +15,17 @@
 #include <signal.h>
 #include "slang.h"
 #include <stdio.h>
-#include <unistd.h>
+#include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <libintl.h>
+#define _(String) gettext (String)
+
+char FG[NUMSCREENPARTS][COLORLEN];
+char BG[NUMSCREENPARTS][COLORLEN];
+
+char *ScreenTitle;
 
 /* equals 1 if the screen is set up in slang mode */
 int screen_is_setup=0;
@@ -48,37 +58,25 @@ void DrawBase (char *base) {
   SLsmg_gotorc(SLtt_Screen_Rows-1,SLtt_Screen_Cols-1);
 }
 
-/* Draw a shadow "under" a given rectangle.
+/* Convert the character at the given screen position to a shadow */
+void _shadow_char (int x, int y) {
+	SLsmg_set_color_in_region(SHADOW, y, x, 1, 1);
+}
+
+/*
+ * Draw a shadow "under" a given rectangle.
  * Shadows are omitted in B&W mode.
  */
 void DrawShadow (int x,int y,int dx,int dy) {
   int c;
-  unsigned short ch;
-
+  
   if (SLtt_Use_Ansi_Colors) {
     for (c=0;c<dy-1;c++) {
-      SLsmg_gotorc(c+1+y,x+dx);
-      /*
-       * Note: 0x02 corresponds to the current color.  0x80FF gets the
-       * character plus alternate character set attribute. -- JED 
-       */
-      ch = SLsmg_char_at();
-      ch = (ch & 0x80FF) | (0x02 << 8);
-      /*
-       * Notice that we have to subtract 1 from the color specification, for 
-       * some reason.
-       */
-      SLsmg_write_raw (&ch,SHADOW - 1);
-      SLsmg_gotorc(c+1+y,x+dx+1);
-      ch = SLsmg_char_at();
-      ch = (ch & 0x80FF) | (0x02 << 8);
-      SLsmg_write_raw (&ch,SHADOW - 1);
+      _shadow_char(x+dx, c+1+y);
+      _shadow_char(x+dx+1, c+1+y);
     }
     for (c=0;c<dx;c++) {
-      SLsmg_gotorc(y+dy,x+2+c);
-      ch = SLsmg_char_at();
-      ch = (ch & 0x80FF) | (0x02 << 8);
-      SLsmg_write_raw (&ch,SHADOW - 1);
+      _shadow_char(x+2+c, y+dy);
     }
   }
 }
@@ -92,7 +90,8 @@ void DrawDialog (char *title,int x,int y,int dx,int dy,int shadow) {
   int c;
   char *empty="";
 
-  SLsmg_draw_box(y,x,dy,dx);
+  if (Borderspace) SLsmg_fill_region(y,x,dy,dx,' ');
+  else SLsmg_draw_box(y,x,dy,dx);
   for(c=y+1;c<y+dy-1;c++) {
     SLsmg_gotorc(c,x+1);
     SLsmg_write_nstring(empty,dx-2);
@@ -127,22 +126,15 @@ RETSIGTYPE Sigwinch_Handler (int sig) {
  */
 void Screen_Init () {
   static int SLkp_init_ran;
-  int fd;
-
+  static int got_terminfo;
+  
   if (screen_is_setup == 0) {
-    /*
-     * Make sure that we have /dev/tty open as stdin. 
-     * You see, if a rc file is passed to pdmenu on stdin, then
-     * after the rc file is read, there is no longer stdin available
-     * for programs pdmenu launches to use.
-     */
-    fd = (int) fopen("/dev/tty","r");
-    dup2(fd, 0);
-    close(fd);
-
     SLsig_block_signals(); /* Block signals while initializing. */
 
-    SLtt_get_terminfo();
+    if (got_terminfo != 1) {
+ 	   SLtt_get_terminfo();
+	   got_terminfo = 1;
+    }
 
     /* note this has to run immediatly after SLtt_get_terminfo to work */
     if (Lowbit)
@@ -151,7 +143,7 @@ void Screen_Init () {
     if (SLkp_init_ran != 1) {
       if (SLkp_init() == -1) {
 	SLsig_unblock_signals();
-	Error(KP_INIT_ERROR);
+	Error(_("Unable to initialize key mappings."));
       }
       SLkp_init_ran=1;
     }
@@ -161,7 +153,7 @@ void Screen_Init () {
     SLtt_Use_Ansi_Colors=Use_Color;
 
     SLsignal(SIGWINCH,Sigwinch_Handler);
-
+    
     SLsig_unblock_signals();
 
     screen_is_setup=1;
@@ -197,5 +189,5 @@ void SetScreensize () {
   SLtt_get_screen_size();
 
   if ((SLtt_Screen_Rows < MIN_ROWS) || (SLtt_Screen_Cols < MIN_COLS))
-    Error(SCREEN_TOOSMALL);
+    Error(_("Error: The screen is too small."));
 }
