@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kitenet.net)
+ * Copyright (c) 1995-2001 Joey Hess (pdmenu@joeyh.name)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
@@ -12,8 +12,10 @@
 
 /* must be long enough for "brightmagenta", our longest color name */
 #define COLORLEN 13
-char FG[NUMSCREENPARTS][COLORLEN];
-char BG[NUMSCREENPARTS][COLORLEN];
+extern char FG[NUMSCREENPARTS][COLORLEN];
+extern char BG[NUMSCREENPARTS][COLORLEN];
+
+extern char *ScreenTitle;
 
 void DrawTitle(char *);
 void DrawDesktop(void);
